<?php
/**
 * Returns theme options
 * Uses sane defaults in case the user has not configured any theme options yet.
 * @package Salal
 * @license http://www.gnu.org/licenses/gpl-2.0.html GNU Public License
 */

/**
* Get a single theme option
* @return mixed
*/
function salal_get_option( $option_name = '' ) {

	// Get all Theme Options from Database.
	$theme_options = salal_theme_options();

	// Return single option.
	if ( isset( $theme_options[ $option_name ] ) ) {
		return $theme_options[ $option_name ];
	}

	return false;
}

/**
 * Get saved user settings from database or theme defaults
 * @return array
 */
function salal_theme_options() {

	// Merge theme options array from database with default options array.
	$theme_options = wp_parse_args( get_option( 'salal_theme_options', array() ), salal_default_options() );

	// Return theme options.
	return $theme_options;
}

/**
 * Returns the default settings of the theme
 * @return array
 */
function salal_default_options() {

	$default_options = array(
		'site_title'          => true,
		'site_description'    => true,
		'theme_layout'        => 'wide',
		'sidebar_position'    => 'right',
		'sidebar_position_post'    => 'right',
		'blog_title'          => '',
		'blog_description'    => '',
		'blog_layout'         => 'large',
		'blog_content'        => 'excerpt',
		'excerpt_length'      => 35,
		'read_more_text'      => esc_html__( 'Continue Reading', 'salal' ),
		'post_category'       => true,
		'meta_date'           => true,
		'meta_author'         => true,
		'meta_category'       => true,
		'meta_tags'           => true,
		'post_navigation'     => true,	
		'crop_large_featured' => false,
		'crop_list_featured' => false,
		'crop_grid_featured' => false,
		'crop_single_featured' => false,		
		'post_image_archives' => true,
		'post_image_single'   => true,
		'post_layout'           => false,
		'display_slider'           => false,
		'display_slide_cat' => true,
		'display_slide_readmore' => false,
		'display_dropcap' => false,
		'slide_count'      => 3,
		'slide_date' => true,
		'slider_cat' => '',
	);

	return $default_options;
}
