<?php
/**
 * Layout Settings
 *
 * Register Layout section, settings and controls for Theme Customizer
 *
 * @package Salal
 */

/**
 * Adds all layout settings to the Customizer
 *
 * @param object $wp_customize / Customizer Object.
 */
function salal_customize_register_layout_settings( $wp_customize ) {


	// Add Section for Theme Options.
	$wp_customize->add_section( 'salal_section_layout', array(
		'title'    => esc_html__( 'Layout Settings', 'salal' ),
		'priority' => 10,
		'panel'    => 'salal_options_panel',
	) );

	// Add Settings and Controls for theme layout.
	$wp_customize->add_setting( 'salal_theme_options[theme_layout]', array(
		'default'           => 'wide',
		'type'              => 'option',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'salal_sanitize_select',
	) );

	$wp_customize->add_control( 'salal_theme_options[theme_layout]', array(
		'label'    => esc_html__( 'Theme Layout', 'salal' ),
		'description'    => esc_html__( 'The Wide Layout is full width with no boxes around content. The Centered Layout is similar but is not full width. The Boxed Layout puts boxes around your content.', 'salal' ),
		'section'  => 'salal_section_layout',
		'type'     => 'select',
		'choices'  => array(
			'wide'     => esc_html__( 'Wide Layout', 'salal' ),
			'centered' => esc_html__( 'Centered Layout', 'salal' ),
			'boxed'    => esc_html__( 'Boxed Layout', 'salal' ),
		),
	) );

	
	// Header nav Width
	$wp_customize->add_setting( 'salal_header_nav_width', array(
		'default'           => '70',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'salal_sanitize_range',
	) );

	$wp_customize->add_control( 'salal_header_nav_width', array(
		'type'            => 'range',
		'section'         => 'salal_section_layout',
		'label'           => esc_html__( 'Header Nav Width', 'salal' ),
		'description'     => esc_html__( 'Adjust the width of the top header navigation area. This only gets applied in desktop viewing.', 'salal' ),
		'input_attrs' => array(
			'min'   => 50,
			'max'   => 100,
			'step'  => 1,
			'style' => 'width: 100%',
		),
	) );	
	
	// Footer Width
	$wp_customize->add_setting( 'salal_footer_width', array(
		'default'           => '70',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'salal_sanitize_range',
	) );

	$wp_customize->add_control( 'salal_footer_width', array(
		'type'            => 'range',
		'section'         => 'salal_section_layout',
		'label'           => esc_html__( 'Footer Width', 'salal' ),
		'description'     => esc_html__( 'Adjust the width of the footer area. This only gets applied in desktop viewing.', 'salal' ),
		'input_attrs' => array(
			'min'   => 50,
			'max'   => 100,
			'step'  => 1,
			'style' => 'width: 100%',
		),
	) );	
	
	// Bottom Sidebar Width
	$wp_customize->add_setting( 'salal_bottom_sidebar_width', array(
		'default'           => '70',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'salal_sanitize_range',
	) );

	$wp_customize->add_control( 'salal_bottom_sidebar_width', array(
		'type'            => 'range',
		'section'         => 'salal_section_layout',
		'label'           => esc_html__( 'Bottom Sidebar Width', 'salal' ),
		'description'     => esc_html__( 'Adjust the width of the bottom sidebars group. This only gets applied in desktop viewing.', 'salal' ),
		'input_attrs' => array(
			'min'   => 50,
			'max'   => 100,
			'step'  => 1,
			'style' => 'width: 100%',
		),
	) );
	
}
add_action( 'customize_register', 'salal_customize_register_layout_settings' );