<?php 
/**
 * Featured image slider, displayed on front page for static page and blog. Recommend that you create a
 * featured category where you can create only featured posts to display in your slides.
 *
 * Function excerpt = custom excerpt length for our slides
 * Function featured slider = Second is our structure for building our slides.
 */

// Build the slides  
if( ! function_exists( 'salal_post_slider' ) ) :
	function salal_post_slider() {

	// Get theme options from database.
	$theme_options = salal_theme_options();
	$display_slider = esc_attr(get_theme_mod( 'salal_display_slider', false ) );
	$slider_cat     = esc_attr(salal_get_option( 'slider_cat' ) );
    $slide_count = esc_attr(salal_get_option( 'slide_count', 3 ) );
				
		if (( is_front_page() || is_home()) && $display_slider ) { 

			$slider_args = array(
				'cat' => $slider_cat,
				'posts_per_page' => $slide_count,
				'meta_query' => array(
					array(
						'key' => '_thumbnail_id',
						'compare' => 'EXISTS',
					),
				),
			);
			$query = new WP_Query( $slider_args ); ?>

<div id="owl-carousel" class="owl-carousel slider-layout-cards">

    <?php if ( $query->have_posts() ) :
				while ( $query->have_posts() ) : $query->the_post(); ?>

    <div class="item">

        <?php	// Check if the post has a featured image						
								 if( has_post_thumbnail() ) {
									the_post_thumbnail( 'salal-slide' );    
								} else { 
								// If no featured image, use the default fallback image ?>
            <img src="<?php echo esc_url( get_stylesheet_directory_uri() . '/assets/images/default-slide.jpg' ) ?>" alt="<?php the_title_attribute(); ?>" />
            <?php
                            }
                            ?>

                <div class="slide-text">
                    <?php
								// Show or hide the slide category name
								if ( true === $theme_options['display_slide_cat'] )  {
                                    salal_get_first_cat_name();
								}
								
								// Slide post title
                                the_title( '<h2 class="title"><a href="' . esc_url( get_permalink() ) . '">', '</a></h2>' );
								
								// Show or hide the slide post date
								if ( esc_attr(get_theme_mod( 'salal_display_slide_date', true ) ) ) {
									echo '<div class="slide-date">' . esc_html(get_the_date()) . '</div>';
								}
								
								// Show or hide the slide read more button
								if ( esc_attr(get_theme_mod( 'salal_display_slide_readmore', true ) ) ) {		
									echo '<a class="more-link slide-more" href="' . esc_url(get_permalink()) . '">' . esc_html__( 'Read More', 'salal' ) . '</a>';
								}
							
                                ?>
                </div>
    </div>

    <?php
					endwhile;
				wp_reset_query();
			endif;
			echo '</div>';
		}
		
	}
endif;
add_action( 'salal_post_slider', 'salal_post_slider', 15 );
